import { models } from "@/constant/models.ts";
import useModelStore from "@/store/useModelStore.ts";
import styles from "./AreaIndicator.module.scss";
import {
  Button,
  ButtonGroup,
  Icon,
  IconButton,
  Popover,
  PopoverArrow,
  PopoverBody,
  PopoverCloseButton,
  PopoverContent,
  PopoverFooter,
  PopoverHeader,
  PopoverTrigger,
} from "@chakra-ui/react";
import { CgArrowsExchange } from "react-icons/cg";
import { useState } from "react";

const AreaIndicator = () => {
  const activeModel = useModelStore((state) => state.activeModel);
  const setActiveModel = useModelStore((state) => state.setActiveModel);
  const activeArea = useModelStore((state) => state.activeArea);
  const setActiveArea = useModelStore((state) => state.setActiveArea);
  const [showModelPicker, setShowModelPicker] = useState(false);
  return (
    <div
      className={
        "absolute left-2 top-1/2 flex -translate-y-1/2 flex-col items-center justify-center rounded bg-red-200 p-2 shadow-lg transition-shadow hover:shadow-2xl"
      }
    >
      <div className={"flex"}>
        <div className={"flex flex-col"}>
          <div className={"text-center text-[10px]"}>切换版型</div>
          <IconButton
            className={"mt-1"}
            onClick={() => {
              setShowModelPicker(() => true);
            }}
            isRound={true}
            boxShadow={"lg"}
            aria-label={"switch"}
            icon={<Icon boxSize={8} as={CgArrowsExchange} />}
          />
        </div>
        <Popover
          closeOnBlur={false}
          placement={"right"}
          onClose={() => {
            setShowModelPicker(() => false);
          }}
          isOpen={showModelPicker}
        >
          <PopoverTrigger>
            <div className={"w-0"}></div>
          </PopoverTrigger>
          <PopoverContent>
            <PopoverHeader fontWeight="semibold">切换版型</PopoverHeader>
            <PopoverArrow />
            <PopoverCloseButton />
            <PopoverBody>
              <div className={"max-h-48 overflow-y-auto p-1"}>
                {models.map((el, index) => (
                  <div
                    onClick={() => {
                      setActiveModel(index);
                      setShowModelPicker(() => false);
                    }}
                    className={`${styles.modelItem} ${
                      activeModel === index ? "bg-blue-50" : ""
                    } flex h-10 cursor-pointer items-center rounded px-3 shadow transition-shadow hover:shadow-lg`}
                    key={el.path}
                  >
                    {el.name}
                  </div>
                ))}
              </div>
            </PopoverBody>
            <PopoverFooter display="flex" justifyContent="flex-end">
              <ButtonGroup size="sm">
                <Button
                  variant="outline"
                  onClick={() => {
                    setShowModelPicker(() => false);
                  }}
                >
                  取消
                </Button>
              </ButtonGroup>
            </PopoverFooter>
          </PopoverContent>
        </Popover>
      </div>

      {models[activeModel].mesh.map((item, index) => (
        <div
          onClick={() => {
            setActiveArea(index);
          }}
          className={`${styles.modelAreaItem} ${
            activeArea === index ? "border-2 border-green-300" : ""
          } h-12 w-12 overflow-hidden rounded transition-all`}
          key={item.name}
        >
          <img
            src={item.icon}
            className={"h-full w-full object-cover"}
            alt={""}
          />
        </div>
      ))}
    </div>
  );
};

export default AreaIndicator;
