import { create } from "zustand";
import { models } from "@/constant/models.ts";

interface ModelState {
  modelLoading: number;
  setModelLoading: (progress: number) => void;

  activeModel: number;
  setActiveModel: (index: number) => void;

  activeArea: number;
  setActiveArea: (index: number) => void;

  activeTextures: number[];
  setActiveTextures: (activeArea: number, activeTexture: number) => void;
}

const useModelStore = create<ModelState>()((set) => ({
  modelLoading: 0,
  setModelLoading: (progress: number) =>
    set(() => ({ modelLoading: progress })),

  activeModel: 0,
  setActiveModel: (index: number) =>
    set(() => ({
      activeModel: index,
      activeArea: 0,
      activeTextures: Array(models[index].mesh.length).fill(0),
    })),

  activeArea: 0,
  setActiveArea: (index: number) => set(() => ({ activeArea: index })),

  activeTextures: Array(models[0].mesh.length).fill(0),
  setActiveTextures: (activeArea: number, activeTexture: number) =>
    set((state) => ({
      activeTextures: state.activeTextures.length
        ? state.activeTextures.map((item, index) =>
            index === activeArea ? activeTexture : item,
          )
        : Array(state.activeTextures.length).fill(0),
    })),
}));

export default useModelStore;
